%define anolis_release 1
%bcond_without snmp
%bcond_without vrrp
%bcond_without sha1
%bcond_without json
%bcond_without nftables
%bcond_with profile
%bcond_with debug

%global _hardened_build 1

Name: keepalived
Summary: High Availability monitor built upon LVS, VRRP and service pollers
Version: 2.3.2
Release: %{anolis_release}%{?dist}
License: GPLv2+
URL: http://www.keepalived.org/

Source0: http://www.keepalived.org/software/keepalived-%{version}.tar.gz
Source1: keepalived.service
#Patch0: keepalived-configure-c99.patch

Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd

%if %{with snmp}
BuildRequires: net-snmp-devel
%endif
%if %{with nftables}
BuildRequires: libmnl-devel
BuildRequires: libnftnl-devel
%else
BuildRequires: ipset-devel
BuildRequires: iptables-devel
%endif
BuildRequires: gcc
BuildRequires: systemd-units
BuildRequires: systemd-devel
BuildRequires: openssl-devel
BuildRequires: libnl3-devel
BuildRequires: libnfnetlink-devel
BuildRequires: file-devel
BuildRequires: make

%description
Keepalived provides simple and robust facilities for load balancing
and high availability to Linux system and Linux based infrastructures.
The load balancing framework relies on well-known and widely used
Linux Virtual Server (IPVS) kernel module providing Layer4 load
balancing. Keepalived implements a set of checkers to dynamically and
adaptively maintain and manage load-balanced server pool according
their health. High availability is achieved by VRRP protocol. VRRP is
a fundamental brick for router failover. In addition, keepalived
implements a set of hooks to the VRRP finite state machine providing
low-level and high-speed protocol interactions. Keepalived frameworks
can be used independently or all together to provide resilient
infrastructures.

%package doc
Summary:        Doc files for %{name}
Requires:       %{name} = %{EVR}
BuildArch:      noarch

%description doc
Doc files for %{name}

%prep
%autosetup -p1

# Prevent re-running autotools.
touch aclocal.m4 Makefile.in lib/config.h.in configure

%build
%configure \
    %{?with_debug:--enable-debug} \
    %{?with_profile:--enable-profile} \
    %{!?with_vrrp:--disable-vrrp} \
    %{?with_snmp:--enable-snmp --enable-snmp-rfc} \
    %{?with_nftables:--enable-nftables --disable-iptables} \
    %{?with_json:--enable-json} \
    %{?with_sha1:--enable-sha1} \
    --with-init=systemd
%{__make} %{?_smp_mflags} STRIP=/bin/true

%install
rm -rf %{buildroot}
make install DESTDIR=%{buildroot}
rm -rf %{buildroot}%{_initrddir}/
rm -rf %{buildroot}%{_sysconfdir}/keepalived/samples/
mv %{buildroot}%{_sysconfdir}/keepalived/keepalived.conf.sample \
   %{buildroot}%{_sysconfdir}/keepalived/keepalived.conf
%{__install} -p -D -m 0644 %{SOURCE1} %{buildroot}%{_unitdir}/keepalived.service
mkdir -p %{buildroot}%{_libexecdir}/keepalived
%generate_compatibility_deps

%post
%systemd_post keepalived.service

%preun
%systemd_preun keepalived.service

%postun
%systemd_postun_with_restart keepalived.service

%files
%attr(0755,root,root) %{_sbindir}/keepalived
%config(noreplace) %attr(0644,root,root) %{_sysconfdir}/sysconfig/keepalived
%config(noreplace) %attr(0644,root,root) %{_sysconfdir}/keepalived/keepalived.conf
%license COPYING
%doc README
%doc doc/keepalived.conf.SYNOPSIS doc/samples/keepalived.conf.*
%dir %{_sysconfdir}/keepalived/
%dir %{_libexecdir}/keepalived/
%if %{with snmp}
%{_datadir}/snmp/mibs/KEEPALIVED-MIB.txt
%{_datadir}/snmp/mibs/VRRP-MIB.txt
%{_datadir}/snmp/mibs/VRRPv3-MIB.txt
%endif
%{_bindir}/genhash
%{_unitdir}/keepalived.service
%{_mandir}/man1/genhash.1*
%{_mandir}/man5/keepalived.conf.5*
%{_mandir}/man8/keepalived.8*
%dir %{abidir}
%{abidir}/keepalived-option.list

%files doc
%doc AUTHOR ChangeLog CONTRIBUTORS README TODO

%changelog
* Tue Nov 26 2024 mgb01105731 <mgb01105731@alibaba-inc.com> - 2.3.2-1
- update to 2.3.2 to fix CVE-2024-41184

* Thu Apr 06 2023 Chunmei Xu <xuchunmei@linux.alibaba.com> - 2.2.7-1
- init from upstream
